<?php
if (! defined('ABSPATH') ) {
    exit;
}

/**
 * Automizely Feed Actions
 */
class Automizely_Feed_Actions
{


    /**
     * Instance of this class.
     *
     * @var object Class Instance
     */
    private static $instance;

    /**
     * Get the class instance
     *
     * @return Automizely_Feed_Actions
     */
    public static function get_instance()
    {
        if (null === self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    /**
     * Add 'modified_after' and 'modified_before' for data query
     *
     * @param  array           $args
     * @param  WP_REST_Request $request
     * @return array
     */
    function add_query( array $args, $request )
    {
        $modified_after  = $request->get_param('modified_after');
        $modified_before = $request->get_param('modified_before');
        if (! $modified_after || ! $modified_before ) {
            return $args;
        };
        $args['date_query'][] = array(
            'column' => 'post_modified',
            'after'  => $modified_after,
            'before' => $modified_before,
        );
        return $args;
    }

    /**
     * Add 'modified' to orderby enum
     *
     * @param array $params
     */
    public function add_collection_params( $params )
    {
        $enums = $params['orderby']['enum'];
        if (! in_array('modified', $enums) ) {
            $params['orderby']['enum'][] = 'modified';
        }
        return $params;
    }

    /**
     * Add 'modified_after' and 'modified_before' for data query
     *
     * @param  array           $args
     * @param  WP_REST_Request $request
     * @return array
     */
    public function add_customer_query( array $args, $request )
    {
        $order           = $request->get_param('order');
        $modified_after  = $request->get_param('modified_after');
        $modified_before = $request->get_param('modified_before');
        if (! $modified_after || ! $modified_before ) {
            return $args;
        };
        // @notice may overwrite other service's query
        $args['meta_query'] = array(
            'modified' => array(
                'key'     => 'last_update',
                'value'   => array( strtotime($modified_after), strtotime($modified_before) ),
                'type'    => 'numeric',
                'compare' => 'BETWEEN',
            ),
        );
        $args['orderby']    = array(
            'modified' => $order ? $order : 'DESC',
        );
        return $args;
    }
}
